@@ -60,14 +60,17 @@ def monascaclient(request, password=None):
     return client
 
 
-def alarm_list(request, offset, limit, marker=None, paginate=False):
+def alarm_list(request, offset=0, limit=10000, marker=None, paginate=False):
     result = monascaclient(request).alarms.list(offset=offset, limit=limit)
     return result['elements'] if type(result) is dict else result
 
 
-def alarm_list_by_service(request, service_name, marker=None, paginate=False):
-    service_dim = {'service': service_name}
-    result = monascaclient(request).alarms.list(dimensions=service_dim)
+def alarm_list_by_service(request, service_name,  offset=0, limit=10000,
+                          marker=None, paginate=False):
+    name, value = service_name.split('=')
+    service_dim = {name: value}
+    result = monascaclient(request).alarms.list(offset=offset, limit=limit,
+                                                metric_dimensions=service_dim)
     return result['elements'] if type(result) is dict else result
 
 
@@ -75,8 +78,8 @@ def alarm_delete(request, alarm_id):
     return monascaclient(request).alarms.delete(alarm_id=alarm_id)
 
 
-def alarm_history(request, alarm_id):
-    result = monascaclient(request).alarms.history(alarm_id=alarm_id)
+def alarm_history(request, alarm_id, offset=0, limit=10000):
+    result = monascaclient(request).alarms.history(alarm_id=alarm_id, offset=offset, limit=limit)
     return result['elements'] if type(result) is dict else result
 
 
@@ -88,8 +91,8 @@ def alarm_patch(request, **kwargs):
     return monascaclient(request).alarms.patch(**kwargs)
 
 
-def alarmdef_list(request, marker=None, paginate=False):
-    result = monascaclient(request).alarm_definitions.list()
+def alarmdef_list(request, offset=0, limit=10000, marker=None, paginate=False):
+    result = monascaclient(request).alarm_definitions.list(offset=offset, limit=limit)
     return result['elements'] if type(result) is dict else result
 
 
@@ -123,8 +126,8 @@ def alarmdef_patch(request, **kwargs):
     return monascaclient(request).alarm_definitions.patch(**kwargs)
 
 
-def notification_list(request, marker=None, paginate=False):
-    result = monascaclient(request).notifications.list()
+def notification_list(request, offset=0, limit=10000, marker=None, paginate=False):
+    result = monascaclient(request).notifications.list(offset=offset, limit=limit)
     return result['elements'] if type(result) is dict else result
 
 
