@@ -19,6 +19,7 @@ import logging
 import urllib
 
 from django.conf import settings  # noqa
+from django.contrib import messages
 from django.core.urlresolvers import reverse_lazy
 from django.http import HttpResponse  # noqa
 from django.views.generic import TemplateView  # noqa
@@ -91,7 +92,9 @@ def get_status(alarms):
 def generate_status(request):
     try:
         alarms = api.monitor.alarm_list(request)
-    except Exception:
+    except Exception as e:
+        messages.error(request,
+                       _('Unable to list alarms: %s') % str(e))
         alarms = []
     alarms_by_service = {}
     for a in alarms:
